結果
| 問題 | No.92 逃走経路 |
| コンテスト | |
| ユーザー |
|
| 提出日時 | 2020-09-03 11:53:15 |
| 言語 | PyPy3 (8.0.0 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 60 ms / 5,000 ms |
| + 927µs | |
| コード長 | 471 bytes |
| 記録 | |
| コンパイル時間 | 87 ms |
| コンパイル使用メモリ | 64,976 KB |
| 実行使用メモリ | 60,160 KB |
| 最終ジャッジ日時 | 2026-10-13 11:36:38 |
| 合計ジャッジ時間 | 2,848 ms |
|
ジャッジサーバーID (参考情報) |
judge1_0 / judge4_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| sample | AC * 2 |
| other | AC * 19 |
ソースコード
N, M, K = map(int, input().split())
V = [[] for i in range(N)]
for i in range(M):
a, b, c = map(int, input().split())
V[a - 1] += [[b - 1, c]]
V[b - 1] += [[a - 1, c]]
dp = [1] * N
for k in map(int, input().split()):
dp1 = [0] * N
for i in range(N):
if dp[i]:
for v, c in V[i]:
if c == k:
dp1[v] = 1
dp = dp1
print(sum(dp))
print(*(i + 1 for i in range(N) if dp[i]))